Ext.namespace('Zarafa.plugins.files.backend.SMB');

/**
 * @class Zarafa.plugins.files.backend.SMB.FormConfig
 *
 * This class provides functions that are used in the plugin settings UI.
 */
Zarafa.plugins.files.backend.SMB.FormConfig = {
	/**
	 * Event handler called when the "use Kopano credentials" checkbox has been modified
	 *
	 * @param {Ext.form.CheckBox} checkbox Checkbox element from which the event originated
	 * @param {Boolean} checked State of the checkbox
	 */
	onCheckCredentials: function (checkbox, checked) {
		if (checked) {
			this.usernameField.hide();
			this.usernameField.label.hide();
			this.passwordField.hide();
			this.passwordField.label.hide();
		} else {
			this.usernameField.show();
			this.usernameField.label.show();
			this.passwordField.show();
			this.passwordField.label.show();
		}
	}
};
Ext.namespace('Zarafa.plugins.files.backend.SMB');

/**
 *
 * @class Zarafa.plugins.files.backend.SMB.SMBBackend
 * @extends Zarafa.core.Plugin
 *
 * Plugin for the SMB backend. It requires the main files plugin.
 */
Zarafa.plugins.files.backend.SMB.SMBBackend = Ext.extend(Zarafa.core.Plugin, {

	/**
	 * Constructor
	 * @protected
	 */
	constructor: function (config) {
		config = config || {};

		Zarafa.plugins.files.backend.SMB.SMBBackend.superclass.constructor.call(this, config);
	},

	/**
	 * Initialze all insertion points.
	 */
	initPlugin: function () {
		Zarafa.plugins.files.backend.SMB.SMBBackend.superclass.initPlugin.apply(this, arguments);
	}
});

// Register plugin
Zarafa.onReady(function () {
	container.registerPlugin(new Zarafa.core.PluginMetaData({
		name             : 'filesbackendSMB', // this name must be in format "filesbackend<Backendname>"
		displayName      : _('Files: SMB/CIFS Backend'),
		allowUserDisable : false, // don't allow to disable this plugin - files will get confused if it is disabled
		pluginConstructor: Zarafa.plugins.files.backend.SMB.SMBBackend
	}));
});